# Contributors

BioSimulators-utils was developed with help from the following people:

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://www.karrlab.org"><img src="https://avatars.githubusercontent.com/u/2848297?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jonathan Karr</b></sub></a><br /><a href="https://github.com/biosimulators/Biosimulators_utils/commits?author=jonrkarr" title="Code">💻</a></td>
    <td align="center"><a href="http://bshaikh.com"><img src="https://avatars.githubusercontent.com/u/32490144?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Bilal Shaikh</b></sub></a><br /><a href="https://github.com/biosimulators/Biosimulators_utils/issues?q=author%3Abilalshaikh42" title="Bug reports">🐛</a> <a href="https://github.com/biosimulators/Biosimulators_utils/commits?author=bilalshaikh42" title="Code">💻</a> <a href="#ideas-bilalshaikh42" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://ankursinha.in/"><img src="https://avatars.githubusercontent.com/u/102575?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ankur Sinha</b></sub></a><br /><a href="#tool-sanjayankur31" title="Tools">🔧</a></td>
    <td align="center"><a href="http://www.opensourcebrain.org/"><img src="https://avatars.githubusercontent.com/u/1556687?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Padraig Gleeson</b></sub></a><br /><a href="#tool-pgleeson" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/dilawar"><img src="https://avatars.githubusercontent.com/u/895681?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Dilawar Singh</b></sub></a><br /><a href="#tool-dilawar" title="Tools">🔧</a></td>
    <td align="center"><a href="http://www.smoldyn.org/"><img src="https://avatars.githubusercontent.com/u/33039297?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Steve Andrews</b></sub></a><br /><a href="#tool-ssandrews" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/abulovic"><img src="https://avatars.githubusercontent.com/u/1510530?v=4?s=100" width="100px;" alt=""/><br /><sub><b>abulovic</b></sub></a><br /><a href="#tool-abulovic" title="Tools">🔧</a></td>
  </tr>
  <tr>
    <td align="center"><a href="http://genome.jouy.inra.fr/~wliebermeis/index_en.html"><img src="https://avatars.githubusercontent.com/u/3976679?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Wolfram Liebermeister</b></sub></a><br /><a href="#tool-liebermeister" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/yexilein"><img src="https://avatars.githubusercontent.com/u/30040612?v=4?s=100" width="100px;" alt=""/><br /><sub><b>yexilein</b></sub></a><br /><a href="#tool-yexilein" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/AnneGoelzer"><img src="https://avatars.githubusercontent.com/u/32333634?v=4?s=100" width="100px;" alt=""/><br /><sub><b>AnneGoelzer</b></sub></a><br /><a href="#tool-AnneGoelzer" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/obodeit"><img src="https://avatars.githubusercontent.com/u/38722594?v=4?s=100" width="100px;" alt=""/><br /><sub><b>obodeit</b></sub></a><br /><a href="#tool-obodeit" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/MarcDinh"><img src="https://avatars.githubusercontent.com/u/50445930?v=4?s=100" width="100px;" alt=""/><br /><sub><b>MarcDinh</b></sub></a><br /><a href="#tool-MarcDinh" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/Ermentrout"><img src="https://avatars.githubusercontent.com/u/7952422?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ermentrout</b></sub></a><br /><a href="#tool-Ermentrout" title="Tools">🔧</a></td>
    <td align="center"><a href="https://hellix.com/Alan/"><img src="https://avatars.githubusercontent.com/u/602265?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Alan Garny</b></sub></a><br /><a href="#tool-agarny" title="Tools">🔧</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/hsorby"><img src="https://avatars.githubusercontent.com/u/778048?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Hugh Sorby</b></sub></a><br /><a href="#tool-hsorby" title="Tools">🔧</a></td>
    <td align="center"><a href="http://bionetgen.org/"><img src="https://avatars.githubusercontent.com/u/8277248?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jim Faeder</b></sub></a><br /><a href="#tool-jrfaeder" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/ASinanSaglam"><img src="https://avatars.githubusercontent.com/u/11724447?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ali Sinan Saglam</b></sub></a><br /><a href="#tool-ASinanSaglam" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/fbergmann"><img src="https://avatars.githubusercontent.com/u/949059?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Frank Bergmann</b></sub></a><br /><a href="#ideas-fbergmann" title="Ideas, Planning, & Feedback">🤔</a> <a href="#tool-fbergmann" title="Tools">🔧</a></td>
    <td align="center"><a href="http://www.sys-bio.org/"><img src="https://avatars.githubusercontent.com/u/1054990?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Herbert Sauro</b></sub></a><br /><a href="#ideas-hsauro" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://github.com/luciansmith"><img src="https://avatars.githubusercontent.com/u/1736150?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Lucian Smith</b></sub></a><br /><a href="#ideas-luciansmith" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://github.com/moraru"><img src="https://avatars.githubusercontent.com/u/7397814?v=4?s=100" width="100px;" alt=""/><br /><sub><b>moraru</b></sub></a><br /><a href="#ideas-moraru" title="Ideas, Planning, & Feedback">🤔</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://livermetabolism.com/"><img src="https://avatars.githubusercontent.com/u/900538?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Matthias König</b></sub></a><br /><a href="#ideas-matthiaskoenig" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://github.com/cjmyers"><img src="https://avatars.githubusercontent.com/u/3507191?v=4?s=100" width="100px;" alt=""/><br /><sub><b>cjmyers</b></sub></a><br /><a href="#ideas-cjmyers" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://eagmon.github.io/"><img src="https://avatars.githubusercontent.com/u/6809431?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Eran Agmon</b></sub></a><br /><a href="#ideas-eagmon" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="http://allencell.org/"><img src="https://avatars.githubusercontent.com/u/9079?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ryan Spangler</b></sub></a><br /><a href="#ideas-prismofeverything" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://github.com/0u812"><img src="https://avatars.githubusercontent.com/u/7402146?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Kyle Medley</b></sub></a><br /><a href="#ideas-0u812" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://github.com/vcellmike"><img src="https://avatars.githubusercontent.com/u/29076280?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Michael Blinov</b></sub></a><br /><a href="#ideas-vcellmike" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="http://about.me/david.nickerson"><img src="https://avatars.githubusercontent.com/u/811244?v=4?s=100" width="100px;" alt=""/><br /><sub><b>David Nickerson</b></sub></a><br /><a href="#ideas-nickerso" title="Ideas, Planning, & Feedback">🤔</a> <a href="#tool-nickerso" title="Tools">🔧</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/jhgennari"><img src="https://avatars.githubusercontent.com/u/2684850?v=4?s=100" width="100px;" alt=""/><br /><sub><b>John Gennari</b></sub></a><br /><a href="#ideas-jhgennari" title="Ideas, Planning, & Feedback">🤔</a> <a href="#tool-jhgennari" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/CiaranWelsh"><img src="https://avatars.githubusercontent.com/u/19502680?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ciaran Welsh</b></sub></a><br /><a href="#tool-CiaranWelsh" title="Tools">🔧</a></td>
    <td align="center"><a href="https://research.pasteur.fr/en/member/anna-zhukova"><img src="https://avatars.githubusercontent.com/u/10465838?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Anna Zhukova</b></sub></a><br /><a href="#data-annazhukova" title="Data">🔣</a></td>
    <td align="center"><a href="https://www.linkedin.com/in/zakandrewking/"><img src="https://avatars.githubusercontent.com/u/1250400?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Zachary A. King</b></sub></a><br /><a href="#data-zakandrewking" title="Data">🔣</a></td>
    <td align="center"><a href="https://github.com/joncison"><img src="https://avatars.githubusercontent.com/u/1506863?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jon Ison</b></sub></a><br /><a href="#data-joncison" title="Data">🔣</a></td>
    <td align="center"><a href="https://orcid.org/0000-0002-1509-4981"><img src="https://avatars.githubusercontent.com/u/992660?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Matúš Kalaš</b></sub></a><br /><a href="#data-matuskalas" title="Data">🔣</a></td>
    <td align="center"><a href="https://uk.linkedin.com/in/manuelbernal"><img src="https://avatars.githubusercontent.com/u/8855107?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Manuel Bernal Llinares</b></sub></a><br /><a href="#data-mbdebian" title="Data">🔣</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

A key to these emojis is available [here](https://allcontributors.org/docs/en/emoji-key).

## Contributing to BioSimulators utils
We enthusiastically welcome contributions to BioSimulators utils! Please see the [guide to contributing](CONTRIBUTING.md) and the [developer's code of conduct](CODE_OF_CONDUCT.md). 
